// -*- c++ -*-
//------------------------------------------------------------------------------
// $Id: MultichoiceQuestionUI.cpp,v 1.2 2009/07/21 03:07:58 vlg Exp $
//------------------------------------------------------------------------------
//                        MultichoiceQuestionUI.cpp
//------------------------------------------------------------------------------
//  Copyright (c) Vladislav Grinchenko
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//------------------------------------------------------------------------------
//
// Creation Date : Thu, 16 Jul 2009 10:10:45 -0400
//
//------------------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#    include "config.h"
#endif

#include "Granule-main.h"
#include "Granule.h"
#include "GrappConf.h"
#include "MultichoiceQuestionUI.h"
#include "MultichoiceQuestionDB.h"

#include "Intern.h"             // i18n macros

using sigc::mem_fun;
using sigc::bind;

using namespace Gtk;

MultichoiceQuestionUI::
MultichoiceQuestionUI (TextView* question_)
	: 
	m_question_text (question_)
{
	trace_with_mask("MultichoiceQuestionUI::ctor",GUITRACE);

	m_multichoice_checkb = 
		manage (new CheckButton (_("Multichoice")));
	m_multianswer_checkb = 
		manage (new CheckButton (_("Multianswer")));

	m_enable_answer_checkb = 
		manage (new CheckButton (_("Enable")));
	m_correct_answer_checkb = 
		manage (new CheckButton (_("Correct Answer")));

	m_hbox_upper = manage (new HBox (false, 0));
	m_hbox_lower = manage (new HBox (false, 0));

	m_hbox_upper->pack_start (*m_multichoice_checkb, PACK_SHRINK, 0);
	m_hbox_upper->pack_start (*m_multianswer_checkb, PACK_SHRINK, 0);

	m_hbox_lower->pack_start (*m_enable_answer_checkb,  PACK_SHRINK, 0);
	m_hbox_lower->pack_start (*m_correct_answer_checkb, PACK_SHRINK, 0);

	m_notebook = manage (new Notebook ());

	SET_CHECKBUTTON(m_multichoice_checkb);
	SET_CHECKBUTTON(m_multianswer_checkb);
	SET_CHECKBUTTON(m_enable_answer_checkb);
	SET_CHECKBUTTON(m_correct_answer_checkb);

    m_notebook->set_tab_pos (Gtk::POS_LEFT);
    m_notebook->set_show_border (true);

	Pango::FontDescription text_font = CONFIG->fonts_db ().get_example_font ();

	TextView* text_viewp = 0;
	Label*    qlabel     = 0;

	qlabel = manage (new Label (_("Question")));
	qlabel->set_angle (90.0);
/*
	qlabel = manage (new Label ());
	Granule::rotate_label (qlabel, 90.0, _("Question"));
*/
    m_notebook->pages ().push_back (
		Notebook_Helpers::TabElem (*m_question_text, *qlabel));

	for (int i = 0; i < MultichoiceQuestionDB::MAX_CHOICES; i++) 
	{
		text_viewp = manage (new TextView ());
		text_viewp->modify_font (text_font);

		// @todo IS_HILDON - implement external text buffer workaround

		SET_CV_TEXT(text_viewp);
		m_multiq_text_list.push_back (text_viewp);

		qlabel = manage (new Label (MultichoiceQuestionDB::get_choice_tag (i)));
		qlabel->set_angle (90.0);
/*
		qlabel = manage (new Label ());
		Granule::rotate_label (qlabel, 90.0, 
							   MultichoiceQuestionDB::get_choice_tag (i));
*/
		m_notebook->pages ().push_back (
			Notebook_Helpers::TabElem (*text_viewp, *qlabel));
	}

	m_notebook->signal_switch_page ().connect (
		mem_fun (*this, &MultichoiceQuestionUI::on_question_tab_clicked));
}

void
MultichoiceQuestionUI::
on_question_tab_clicked (GtkNotebookPage* page_, guint page_num_)
{
	trace_with_mask("MultichoiceQuestionUI::on_question_tab_clicked",GUITRACE);

	// @todo What am I to do with this signal?
}


void
MultichoiceQuestionUI::
set_text (uint32_t tag_, Glib::ustring text_)
{
	trace_with_mask("MultichoiceQuestionUI::set_text",GUITRACE);

	m_multiq_text_list [tag_]->get_buffer ()->set_text (text_);
}

Glib::ustring
MultichoiceQuestionUI::
get_text (uint32_t tag_)
{
	trace_with_mask("MultichoiceQuestionUI::get_text",GUITRACE);

	return m_multiq_text_list [tag_]->get_buffer ()->get_text ();
}

/*

void
MultichoiceQuestionUI::
 ()
{
	trace_with_mask("MultichoiceQuestionUI::",GUITRACE);

}

*/
