// -*- c++ -*-
//------------------------------------------------------------------------------
// $Id: MultichoiceQuestionUI.h,v 1.2 2009/07/21 03:07:58 vlg Exp $
//------------------------------------------------------------------------------
//                        MultichoiceQuestionUI.h
//------------------------------------------------------------------------------
//  Copyright (c) Vladislav Grinchenko
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//------------------------------------------------------------------------------
//
// Creation Date : Thu, 16 Jul 2009 10:10:45 -0400
//
//------------------------------------------------------------------------------

#ifndef MULTICHOICE_QUESTION_UI_H
#define MULTICHOICE_QUESTION_UI_H

#include <inttypes.h>

#include <gtkmm/checkbutton.h>
#include <gtkmm/notebook.h>
#include <gtkmm/box.h>
#include <gtkmm/textview.h>

#include <string>
using std::string;

#include <vector>

/**
 * @class MultichoiceQuestionUI 
 *
 * Multichoice question entry UI.
 *
 * This class represents multichoice questions encapsulated by
 * MultichoiceQuestionDB database class.
 */

class MultichoiceQuestionUI
{
public:
	typedef std::vector<Gtk::TextView*> questions_list_t;
	typedef questions_list_t::iterator qlist_iterator;

public:
	MultichoiceQuestionUI (Gtk::TextView* question_);

	Gtk::CheckButton* multichoice_check_button    ();
	Gtk::CheckButton* multianswer_check_button    ();
	Gtk::CheckButton* enable_answer_check_button  ();
	Gtk::CheckButton* correct_answer_check_button ();

	Gtk::Notebook* notebook () { return m_notebook; }

	void set_text (uint32_t tag_, Glib::ustring text_);
	Glib::ustring get_text (uint32_t tag_);

	Gtk::HBox* upper_buttons () { return m_hbox_upper; }
	Gtk::HBox* lower_buttons () { return m_hbox_lower; }

private:
	/// User selects one of the multichoice question tabs
	void on_question_tab_clicked (GtkNotebookPage* page_, guint page_num_);

private:
	Gtk::CheckButton* m_multichoice_checkb;
	Gtk::CheckButton* m_multianswer_checkb;
	Gtk::CheckButton* m_enable_answer_checkb;
	Gtk::CheckButton* m_correct_answer_checkb;

	Gtk::HBox* m_hbox_upper;
	Gtk::HBox* m_hbox_lower;

	Gtk::Notebook*    m_notebook;
	Gtk::TextView*    m_question_text;
	questions_list_t  m_multiq_text_list;
};

inline Gtk::CheckButton* 
MultichoiceQuestionUI::
multichoice_check_button ()
{
	return m_multichoice_checkb;
}

inline Gtk::CheckButton*
MultichoiceQuestionUI::
multianswer_check_button ()
{
	return m_multianswer_checkb;
}

inline Gtk::CheckButton*
MultichoiceQuestionUI::
enable_answer_check_button ()
{
	return m_enable_answer_checkb;
}

inline Gtk::CheckButton*
MultichoiceQuestionUI::
correct_answer_check_button ()
{
	return m_correct_answer_checkb;
}

#endif // MULTICHOICE_QUESTION_UI_H
